==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/forum/lang/forum_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'ai articles futurs unicament (minga d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'a toi lu articles sensa excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à toi lu articles, levats aquelu que lo fòro es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilisaires si devon abonar en donant li sieui adreças e-mail denant de poder postar li contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion <i>a priòri</i> (li contribucions apareisson pas publicament après validacion dei administrators).', # MODIF
	'bouton_radio_modere_abonnement' => 'sus abonament',
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion à priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicacion immediata dei messatges (li contribucions apareisson sus lo còup que son mandadi, lu administrators li poadon suprimir pi).',

	// D
	'documents_interdits_forum' => 'Documents proïbits dins lo fòro',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca ?',
	'forum' => 'Fòro',
	'forum_acces_refuse' => 'Podètz pas plus accedir en aquelu forums.',
	'forum_attention_dix_caracteres' => '<b>Dàida !</b> lo voastre messatge deu aver au manco dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Dàida !</b> lo voastre titre deu aver au manco tres caractèrs.',
	'forum_attention_trop_caracteres' => '<b>Atencion !</b> lo voastre messatge es tròp long (@compte@ caractèrs) : per si poder registrar, cau pas que passe @max@ caractèrs.', # MODIF
	'forum_avez_selectionne' => 'Avètz seleccionat :',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aquí</a> per continuar.',
	'forum_forum' => 'fòro',
	'forum_info_modere' => 'Aqueu fòro es moderat à priòri : la voastra contribucion apareisserà après èstre estada validada d’un administrator dau sit.', # MODIF
	'forum_lien_hyper' => 'Ligam ipertèxt',
	'forum_message_definitif' => 'Messatge definitieu: mandar au sit',
	'forum_message_trop_long' => 'Lo voastre messatge es tròup lòng. La talha maximala es de 20 000 caractèrs.', # RELIRE
	'forum_ne_repondez_pas' => 'Respondatz pas à-n-aquel e-mail ma sus lo fòro à l’adreça seguenta : ',
	'forum_page_url' => '(se lo voastre messatge si referisse à un article publicat sus lo web, ò à una pàgina que fornisse mai d’informacions, podetz marcar çai sota lo titre de la pàgina e la sieu adreça.)',
	'forum_poste_par' => 'Messatge postat @parauteur@ à la seguida de l’article « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => 'Cu siètz ?',
	'forum_texte' => 'Tèxt dau voastre messatge',
	'forum_titre' => 'Titre',
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Validar aquesta chausida',
	'forum_voir_avant' => 'Veire aqueu messatge denant de lo postar', # MODIF
	'forum_votre_email' => 'La voastra adreça e-mail',
	'forum_votre_nom' => 'Lo voastre nom',
	'forum_vous_enregistrer' => 'Per participar à
  aquest fòro, vos devètz registrar d’en premier. Mercé
  d’indicar çai sota l’identificant personau que vos es
  estat fornit. Se siètz pas registrat, devètz',
	'forum_vous_inscrire' => 'vos marcar.',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau fòro public : @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerar lu fòros',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar lu fòros publics, vorgatz chausir lu sieus mòde
 de moderacion predefinits:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion :',
	'info_desactiver_forum_public' => 'Desactivar l’utilisacion dei fòros publics. Lu fòros publics podràn èstre autorisats au cas per cas sus lu articles; seràn proïbits sus li rubricas, brèvas, eca.',
	'info_envoi_forum' => 'Mandadís dei fòros ai autors dei articles',
	'info_fonctionnement_forum' => 'Foncionament dau fòro :',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>seguit dei fòros</i> es una aisina de gestion dau voastre sit (ma es pas un espaci de discussion ò de redaccion). Fa paréisser toti li contribucions dei fòros dau sit, autant ben aqueli dau sit public coma de l’espaci privat e vos permete de gerar aqueli contribucions.', # MODIF
	'info_liens_syndiques_3' => 'fòros',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'fòro',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en aspèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei fòros publics',
	'info_option_email' => 'Quora un visitaire dau sit poasta un messatge novèu dins lo fòro associat à un article, lu autors de l’article poadon èstre avertits d’aqueu messatge per corrier electronic. Indicatz per cada tipe de fòro se cau utilisar aquela opcion.',
	'info_pas_de_forum' => 'Minga de fòro',
	'item_activer_forum_administrateur' => 'Activar lo fòro dei administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo fòro dei administrators',

	// L
	'lien_reponse_article' => 'Respoasta à l’article',
	'lien_reponse_breve_2' => 'Respoasta à la brèva',
	'lien_reponse_rubrique' => 'Respoasta à la rubrica',
	'lien_reponse_site_reference' => 'Respoasta au sit referençat',

	// O
	'onglet_messages_internes' => 'Messatges internes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respoandre à-n-aqueu messatge',

	// S
	'statut_original' => 'originau',

	// T
	'titre_cadre_forum_administrateur' => 'Fòro privat dei administrators',
	'titre_cadre_forum_interne' => 'Fòro interne',
	'titre_forum' => 'Fòro',
	'titre_forum_suivi' => 'Seguit dei fòros',
	'titre_page_forum_suivi' => 'Seguit dei fòros'
);

?>

==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/forum/lang/forum_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'ai articles futurs unicament (minga d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'a toi lu articles sensa excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à toi lu articles, levats aquelu que lo fòro es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilisaires si devon abonar en donant li sieui adreças e-mail denant de poder postar li contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion <i>a priòri</i> (li contribucions apareisson pas publicament après validacion dei administrators).', # MODIF
	'bouton_radio_modere_abonnement' => 'sus abonament',
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion à priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicacion immediata dei messatges (li contribucions apareisson sus lo còup que son mandadi, lu administrators li poadon suprimir pi).',

	// D
	'documents_interdits_forum' => 'Documents proïbits dins lo fòro',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca ?',
	'forum' => 'Fòro',
	'forum_acces_refuse' => 'Podètz pas plus accedir en aquelu forums.',
	'forum_attention_dix_caracteres' => '<b>Dàida !</b> lo voastre messatge deu aver au manco dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Dàida !</b> lo voastre titre deu aver au manco tres caractèrs.',
	'forum_attention_trop_caracteres' => '<b>Atencion !</b> lo voastre messatge es tròp long (@compte@ caractèrs) : per si poder registrar, cau pas que passe @max@ caractèrs.', # MODIF
	'forum_avez_selectionne' => 'Avètz seleccionat :',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aquí</a> per continuar.',
	'forum_forum' => 'fòro',
	'forum_info_modere' => 'Aqueu fòro es moderat à priòri : la voastra contribucion apareisserà après èstre estada validada d’un administrator dau sit.', # MODIF
	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitieu: mandar au sit',
	'forum_message_trop_long' => 'Lo voastre messatge es tròup lòng. La talha maximala es de 20000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas à-n-aquel e-mail ma sus lo fòro à l’adreça seguenta : ', # MODIF
	'forum_page_url' => '(se lo voastre messatge si referisse à un article publicat sus lo web, ò à una pàgina que fornisse mai d’informacions, podetz marcar çai sota lo titre de la pàgina e la sieu adreça.)',
	'forum_poste_par' => 'Messatge postat @parauteur@ à la seguida de l’article « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Cu siètz ?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt dau voastre messatge :', # MODIF
	'forum_titre' => 'Titre :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Validar aquesta chausida',
	'forum_voir_avant' => 'Veire aqueu messatge denant de lo postar', # MODIF
	'forum_votre_email' => 'La voastra adreça e-mail :', # MODIF
	'forum_votre_nom' => 'Lo voastre nom (ò pseudonim) :', # MODIF
	'forum_vous_enregistrer' => 'Per participar à
  aquest fòro, vos devètz registrar d’en premier. Mercé
  d’indicar çai sota l’identificant personau que vos es
  estat fornit. Se siètz pas registrat, devètz',
	'forum_vous_inscrire' => 'vos marcar.',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau fòro public : @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerar lu fòros',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar lu fòros publics, vorgatz chausir lu sieus mòde
 de moderacion predefinits:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion :',
	'info_desactiver_forum_public' => 'Desactivar l’utilisacion dei fòros publics. Lu fòros publics podràn èstre autorisats au cas per cas sus lu articles; seràn proïbits sus li rubricas, brèvas, eca.',
	'info_envoi_forum' => 'Mandadís dei fòros ai autors dei articles',
	'info_fonctionnement_forum' => 'Foncionament dau fòro :',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>seguit dei fòros</i> es una aisina de gestion dau voastre sit (ma es pas un espaci de discussion ò de redaccion). Fa paréisser toti li contribucions dei fòros dau sit, autant ben aqueli dau sit public coma de l’espaci privat e vos permete de gerar aqueli contribucions.', # MODIF
	'info_liens_syndiques_3' => 'fòros',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'fòro',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en aspèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei fòros publics',
	'info_option_email' => 'Quora un visitaire dau sit poasta un messatge novèu dins lo fòro associat à un article, lu autors de l’article poadon èstre avertits d’aqueu messatge per corrier electronic. Indicatz per cada tipe de fòro se cau utilisar aquela opcion.',
	'info_pas_de_forum' => 'Minga de fòro',
	'item_activer_forum_administrateur' => 'Activar lo fòro dei administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo fòro dei administrators',

	// L
	'lien_reponse_article' => 'Respoasta à l’article',
	'lien_reponse_breve_2' => 'Respoasta à la brèva',
	'lien_reponse_rubrique' => 'Respoasta à la rubrica',
	'lien_reponse_site_reference' => 'Respoasta au sit referençat :', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges internes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respoandre à-n-aqueu messatge',

	// S
	'statut_original' => 'originau',

	// T
	'titre_cadre_forum_administrateur' => 'Fòro privat dei administrators',
	'titre_cadre_forum_interne' => 'Fòro interne',
	'titre_forum' => 'Fòro',
	'titre_forum_suivi' => 'Seguit dei fòros',
	'titre_page_forum_suivi' => 'Seguit dei fòros'
);

?>
